\name{gladeXMLAutoconnect}
\alias{gladeXMLAutoconnect}
\title{Register signals in Glade interface}
\description{
  This function is used
  to register some or all of
  the callback specifications for a Glade interface.
  It loops over the signal specifications in the Glade
  description and invokes an R function
  to do the actual registration.
  That function is given the information for that signal
  and can interpret it as appropriate.
  This allows us to interpret the callback information
  from glade in different customized ways
  simply by specifying different functions.
}
\usage{
gladeXMLAutoconnect(xml, f = gladeXMLDefaultConnect, name = character(0))
}
\arguments{
  \item{xml}{the \code{GladeXML} interface description object typically obtained
    from \code{\link{gladeXMLNew}} or \code{\link{gladeXMLNewWithDomain}}}
  \item{f}{the function to call to do the connection}
  \item{name}{a character vector giving the names of the signal
    handlers.
    See \code{glade_xml_connect_full} in the libglade API.
    As I understand it from a brief reading, this sets the given R
    function to all signals in the GladeXML file with the given signal
    handler name.
  }
}

\value{
 The return value is always NULL.
 What matters is the side effects of registering
 the callbacks.
}
\references{
  Glade - \url{http://glade.pn.org}
  libglade -  \url{http://developer.gnome.org/doc/API/libglade/libglade.html}
  RGtk  
}
\author{Duncan Temple Lang <duncan@research.bell-labs.com>}


\seealso{
 \code{\link{gladeXMLNew}}
 \code{\link{gladeXMLNewWithDomain}}
 \code{\link{gladeXMLDefaultConnect}}
 \code{\link[RGtk]{gtkObjectAddCallback}}
 \code{\link[RGtk]{gtkObjectSignalConnect}}  
}

\examples{
  x <- gladeXMLNew(system.file("examples", "sample1.glade", package = "RGtkGlade"))

  foo <- function(b, str) {
     cat("In foo callback\n")
     print(b)
     print(str)
  }

  gladeXMLAutoconnect(x)
}
\keyword{interface}

